# [Datta Able](https://app-generator.dev/product/datta-able/) Django Integration

Modern template for **Django** built with **[Datta Able](https://app-generator.dev/product/datta-able/)**, an open-source `Bootstrap` UI Kit released by [CodedThemes](https://app-generator.dev/agency/codedthemes/).

- [Django Admin Datta Able](https://app-generator.dev/docs/products/django-libs/theme-datta-able.html) - Documentation & Support Links
- [Django Datta Able Dashboard](https://app-generator.dev/product/datta-able/django/) - The product that uses the library
- [Getting Started with Django](https://app-generator.dev/docs/technologies/django/index.html) - Learn how to code **Django** Projects

<br />

## **Features**

- [Datta Able](https://app-generator.dev/docs/templates/bootstrap/datta-able.html) Design Integration
  - Dashboard page
  - Color, Typography, Icons 
  - Authentication: Login, Register
  
<br />

## [Datta Able](https://app-generator.dev/product/datta-able/) Starters

Pre-built starters for coding dashboards and services (APIs, DataTables) with speed.

### [Django Datta Able](https://app-generator.dev/product/datta-able/django/)

> The FREE Version (MIT License) - [Live Demo](https://django-datta.onrender.com/).

- Simple, Easy-to-Extend Codebase
- [Datta Able](https://app-generator.dev/product/datta-able/) Integration 
- Bootstrap Styling 
- Dynamic Tables
- Dynamic API
- Charts
- **CLI for Coding Tasks**
  - `Commit/rollback Git Changes`
  - `Backup & restore DB`
  - `Interact with Django Core` via CLI
  - `Update Environment variables`
  - `Update Dependencies`
- Session-based Authentication, Password recovery
- DB Persistence: SQLite (default), can be used with MySql, PgSql
- Docker, CI/CD for Render
- [Vite](https://app-generator.dev/docs/technologies/vite/index.html) for assets management

![Django Datta Able - Open-Source Django Starter](https://user-images.githubusercontent.com/51070104/176118649-7233ffbc-6118-4f56-8cda-baa81d256877.png)

<br />

## [Django Datta Able PRO](https://app-generator.dev/product/datta-able-pro/django/)

> The premium version provides more features, priority on support, and is more often updated - [Live Demo](https://django-datta-pro.onrender.com/).

- Simple, Easy-to-Extend Codebase
- [Datta Able](https://app-generator.dev/product/datta-able/) PRO Design Integration 
- Bootstrap Styling 
- Dynamic Tables - read [docs](https://app-generator.dev/docs/developer-tools/dynamic-datatables.html)
- Dynamic API - read [docs](https://app-generator.dev/docs/developer-tools/dynamic-api.html)
- Charts
- Session-based Authentication, Password recovery
- OAuth (GitHub & Google)
- DB Persistence: SQLite (default), can be used with MySql, PgSql
- [Django CLI Package](https://app-generator.dev/docs/developer-tools/django-cli/index.html)
    - [Commit/rollback Git Changes](https://app-generator.dev/docs/developer-tools/django-cli/git-interface.html)
    - `Backup & restore DB`
    - [Interact with Django Core](https://app-generator.dev/docs/developer-tools/django-cli/query-django.html)
    - `Manage Environment`
    - `Manage Dependencies`
- Session-based Authentication, Password recovery
- DB Persistence: SQLite (default), can be used with MySql, PgSql
- Docker, CI/CD for Render
- [Vite](https://app-generator.dev/docs/technologies/vite/index.html) for assets management

![Datta Able PRO - Full-Stack Starter generated by AppSeed.](https://user-images.githubusercontent.com/51070104/170474361-a58da82b-fff9-4a59-81a8-7ab99f478f48.png)

<br />

## `Customize` with [Django App Generator](https://app-generator.dev/tools/django-generator/)

- Access the [App Generator](https://app-generator.dev/tools/django-generator/) page
- Select the preferred design
- (Optional) Design Database: edit models and fields
- (Optional) Edit the fields for the extended user model
- (Optional) Enable OAuth for GitHub
- (Optional) Add Celery (async tasks)
- (Optional) Enable Dynamic API Module
- Docker Scripts
- Render CI/Cd Scripts

**The generated Django project is available as a ZIP Archive and also uploaded to GitHub.**

![Django Generator - User Interface for choosing the Design](https://github.com/user-attachments/assets/b989c434-1c53-49ff-8dda-b46dbfc142ac) 

![Django App Generator - User Interface for Edit the Extended User Model](https://github.com/user-attachments/assets/f1a5fb68-a5ba-49c9-a3ae-91716de09912) 

<br />

---
**[Datta Able](https://app-generator.dev/product/datta-able/)** Django Integration - Library provided by **[App-Generator](https://app-generator.dev)**
